==> bunny_sdk-0.0.15.tar.gz: bunny_sdk-0.0.15/bunny_sdk/logging_api_client/with_mm_with_dd_with_yy/with_pull_zone_id_log/with_pull_zone_id_log_request_builder.py <==
from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .get_order_query_parameter_type import GetOrderQueryParameterType

class WithPullZoneIdLogRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /{mm}-{dd}-{yy}/{pullZoneId}.log
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]], pull_zone_id: Optional[int] = None) -> None:
        """
        Instantiates a new WithPullZoneIdLogRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param pull_zone_id: The path parameter: pullZoneId
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        if isinstance(path_parameters, dict):
            path_parameters['pullZoneId'] = str(pull_zone_id)
        super().__init__(request_adapter, "{+baseurl}/{mm}-{dd}-{yy}/{pullZoneId}.log?end={end}&order={order}&search={search}&start={start}&status={status}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[WithPullZoneIdLogRequestBuilderGetQueryParameters]] = None) -> bytes:
        """
        [LoggingApi API Docs](https://docs.bunny.net/docs/cdn-logging-api)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: bytes
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_primitive_async(request_info, "bytes", None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[WithPullZoneIdLogRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [LoggingApi API Docs](https://docs.bunny.net/docs/cdn-logging-api)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/gzip")
        return request_info
    
    def with_url(self,raw_url: str) -> WithPullZoneIdLogRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithPullZoneIdLogRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return WithPullZoneIdLogRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class WithPullZoneIdLogRequestBuilderGetQueryParameters():
        """
        [LoggingApi API Docs](https://docs.bunny.net/docs/cdn-logging-api)
        """
        end: Optional[int] = None

        order: Optional[GetOrderQueryParameterType] = None

        search: Optional[str] = None

        start: Optional[int] = None

        status: Optional[str] = None

    
    @dataclass
    class WithPullZoneIdLogRequestBuilderGetRequestConfiguration(RequestConfiguration[WithPullZoneIdLogRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)

==> bunny_sdk-0.0.16.tar.gz: bunny_sdk-0.0.16/bunny_sdk/logging_api_client/with_mm_with_dd_with_yy/with_pull_zone_id_log/with_pull_zone_id_log_request_builder.py <==
from __future__ import annotations
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Callable, Dict, List, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from .get_order_query_parameter_type import GetOrderQueryParameterType

class WithPullZoneIdLogRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /{mm}-{dd}-{yy}/{pullZoneId}.log
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, Dict[str, Any]], pull_zone_id: Optional[int] = None) -> None:
        """
        Instantiates a new WithPullZoneIdLogRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param pull_zone_id: The path parameter: pullZoneId
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        if isinstance(path_parameters, dict):
            path_parameters['pullZoneId'] = pull_zone_id
        super().__init__(request_adapter, "{+baseurl}/{mm}-{dd}-{yy}/{pullZoneId}.log?end={end}&order={order}&search={search}&start={start}&status={status}", path_parameters)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[WithPullZoneIdLogRequestBuilderGetQueryParameters]] = None) -> Optional[bytes]:
        """
        [LoggingApi API Docs](https://docs.bunny.net/docs/cdn-logging-api)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: bytes
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        if not self.request_adapter:
            raise Exception("Http core is null") 
        return await self.request_adapter.send_primitive_async(request_info, "bytes", None)
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[WithPullZoneIdLogRequestBuilderGetQueryParameters]] = None) -> RequestInformation:
        """
        [LoggingApi API Docs](https://docs.bunny.net/docs/cdn-logging-api)
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/gzip")
        return request_info
    
    def with_url(self,raw_url: str) -> WithPullZoneIdLogRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithPullZoneIdLogRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return WithPullZoneIdLogRequestBuilder(self.request_adapter, raw_url)
    
    @dataclass
    class WithPullZoneIdLogRequestBuilderGetQueryParameters():
        """
        [LoggingApi API Docs](https://docs.bunny.net/docs/cdn-logging-api)
        """
        end: Optional[int] = None

        order: Optional[GetOrderQueryParameterType] = None

        search: Optional[str] = None

        start: Optional[int] = None

        status: Optional[str] = None

    
    @dataclass
    class WithPullZoneIdLogRequestBuilderGetRequestConfiguration(RequestConfiguration[WithPullZoneIdLogRequestBuilderGetQueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
